Learn R Programming

mapbayr (version 0.10.2)

est001: Estimation object

Description

An example of mapbayests object, corresponding to the parameter estimation of the 8 subjects from model 1. Note that the model object within is not associated to a shared object, which make some features unavailable. This object can be re-generated by executing est001 <- mapbayest(exmodel(ID = 1:8))

Usage

est001

Arguments

Format

An object of class mapbayests of length 9.

See Also

mapbayest