Pre-process: arguments for optimization function
Source:R/mapbayest_check_and_preprocess.R
preprocess.optim.RdPre-process: arguments for optimization function
Arguments
- x
the model object
- method
optimization method; the default is
"L-BFGS-B"(fromstat::optim()), alternatively"newuoa"forminqa::newuoa()- select_eta
a vector of numeric values, the numbers of the ETAs to be estimated (default is
NULL, all ETAs non-equal to zero)- control
a list passed to the optimizer (see
stats::optim()orminqa::newuoa()documentation)- force_initial_eta
a vector of numeric values to start the estimation from (default to 0 for "L-BFGS-B")
- quantile_bound
a numeric value representing the quantile of the normal distribution admitted to define the bounds for L-BFGS-B (default is 0.001, i.e. 0.1%)