Check if model is valid for 'mapbayr'
Source:R/mapbayest_check_and_preprocess.R
check_mapbayr_model.RdChecks that the model respects points related exclusively to 'mapbayr'. Useful at the time you wish to convert a "regular" 'mrgsolve' model you used for simulation into a model to perform MAP-Bayesian estimation. Note that some elements cannot be checked:
In
$MAINblock, make sure that you addedETA1, ETA2...in the code. For instance:double CL = TVCL * exp(ETA(1) + ETA1) ;.In
$OMEGAblock, make sure the order of the (diagonal) values is the same as for ETAs in$PARAM. For instance, ifETA1corresponds to clearance, the first value in$OMEGAmust be the variance of clearance.In
$SIGMAblock, make sure the order is respected: proportional error first, and additive error secondly.